==> spotbugs-maven-plugin-3.1.3.1-sources.jar: org/codehaus/mojo/spotbugs/SpotbugsViolationCheckMojo.java <==
package org.codehaus.mojo.spotbugs;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

@org.apache.maven.plugins.annotations.Mojo(name="check", defaultPhase=org.apache.maven.plugins.annotations.LifecyclePhase.VERIFY, requiresDependencyResolution=org.apache.maven.plugins.annotations.ResolutionScope.TEST, requiresProject=true, threadSafe=true) @org.apache.maven.plugins.annotations.Execute(goal="spotbugs") public class SpotbugsViolationCheckMojo
  extends org.apache.maven.plugin.AbstractMojo  implements
    groovy.lang.GroovyObject {
;
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.io.File getOutputDirectory() { return (java.io.File)null;}
public  void setOutputDirectory(java.io.File value) { }
public  boolean getXmlOutput() { return false;}
public  boolean isXmlOutput() { return false;}
public  void setXmlOutput(boolean value) { }
public  java.io.File getXmlOutputDirectory() { return (java.io.File)null;}
public  void setXmlOutputDirectory(java.io.File value) { }
public  boolean getSpotbugsXmlOutput() { return false;}
public  boolean isSpotbugsXmlOutput() { return false;}
public  void setSpotbugsXmlOutput(boolean value) { }
public  java.io.File getSpotbugsXmlOutputDirectory() { return (java.io.File)null;}
public  void setSpotbugsXmlOutputDirectory(java.io.File value) { }
public  org.apache.maven.doxia.siterenderer.Renderer getSiteRenderer() { return (org.apache.maven.doxia.siterenderer.Renderer)null;}
public  void setSiteRenderer(org.apache.maven.doxia.siterenderer.Renderer value) { }
public  java.io.File getClassFilesDirectory() { return (java.io.File)null;}
public  void setClassFilesDirectory(java.io.File value) { }
public  java.io.File getTestClassFilesDirectory() { return (java.io.File)null;}
public  void setTestClassFilesDirectory(java.io.File value) { }
public  java.io.File getXrefLocation() { return (java.io.File)null;}
public  void setXrefLocation(java.io.File value) { }
public  java.io.File getXrefTestLocation() { return (java.io.File)null;}
public  void setXrefTestLocation(java.io.File value) { }
public  java.util.List getCompileSourceRoots() { return (java.util.List)null;}
public  void setCompileSourceRoots(java.util.List value) { }
public  java.util.List getTestSourceRoots() { return (java.util.List)null;}
public  void setTestSourceRoots(java.util.List value) { }
public  boolean getIncludeTests() { return false;}
public  boolean isIncludeTests() { return false;}
public  void setIncludeTests(boolean value) { }
public  java.util.List getPluginArtifacts() { return (java.util.List)null;}
public  void setPluginArtifacts(java.util.List value) { }
public  org.apache.maven.artifact.repository.ArtifactRepository getLocalRepository() { return (org.apache.maven.artifact.repository.ArtifactRepository)null;}
public  void setLocalRepository(org.apache.maven.artifact.repository.ArtifactRepository value) { }
public  java.util.List getRemoteArtifactRepositories() { return (java.util.List)null;}
public  void setRemoteArtifactRepositories(java.util.List value) { }
public  org.apache.maven.project.MavenProject getProject() { return (org.apache.maven.project.MavenProject)null;}
public  void setProject(org.apache.maven.project.MavenProject value) { }
public  java.lang.String getXmlEncoding() { return (java.lang.String)null;}
public  void setXmlEncoding(java.lang.String value) { }
public  java.lang.String getSourceEncoding() { return (java.lang.String)null;}
public  void setSourceEncoding(java.lang.String value) { }
public  java.lang.String getOutputEncoding() { return (java.lang.String)null;}
public  void setOutputEncoding(java.lang.String value) { }
public  java.lang.String getThreshold() { return (java.lang.String)null;}
public  void setThreshold(java.lang.String value) { }
public  org.apache.maven.artifact.resolver.ArtifactResolver getArtifactResolver() { return (org.apache.maven.artifact.resolver.ArtifactResolver)null;}
public  void setArtifactResolver(org.apache.maven.artifact.resolver.ArtifactResolver value) { }
public  java.lang.String getIncludeFilterFile() { return (java.lang.String)null;}
public  void setIncludeFilterFile(java.lang.String value) { }
public  java.lang.String getExcludeFilterFile() { return (java.lang.String)null;}
public  void setExcludeFilterFile(java.lang.String value) { }
public  java.lang.String getExcludeBugsFile() { return (java.lang.String)null;}
public  void setExcludeBugsFile(java.lang.String value) { }
public  java.lang.String getEffort() { return (java.lang.String)null;}
public  void setEffort(java.lang.String value) { }
public  java.lang.Boolean getDebug() { return (java.lang.Boolean)null;}
public  void setDebug(java.lang.Boolean value) { }
public  java.lang.Boolean getRelaxed() { return (java.lang.Boolean)null;}
public  void setRelaxed(java.lang.Boolean value) { }
public  java.lang.String getVisitors() { return (java.lang.String)null;}
public  void setVisitors(java.lang.String value) { }
public  java.lang.String getOmitVisitors() { return (java.lang.String)null;}
public  void setOmitVisitors(java.lang.String value) { }
public  java.lang.String getPluginList() { return (java.lang.String)null;}
public  void setPluginList(java.lang.String value) { }
public  java.lang.String getOnlyAnalyze() { return (java.lang.String)null;}
public  void setOnlyAnalyze(java.lang.String value) { }
public  java.lang.Boolean getNested() { return (java.lang.Boolean)null;}
public  void setNested(java.lang.Boolean value) { }
public  java.lang.Boolean getTrace() { return (java.lang.Boolean)null;}
public  void setTrace(java.lang.Boolean value) { }
public  int getMaxRank() { return (int)0;}
public  void setMaxRank(int value) { }
public  boolean getSkip() { return false;}
public  boolean isSkip() { return false;}
public  void setSkip(boolean value) { }
public  org.codehaus.plexus.resource.ResourceManager getResourceManager() { return (org.codehaus.plexus.resource.ResourceManager)null;}
public  void setResourceManager(org.codehaus.plexus.resource.ResourceManager value) { }
public  org.apache.maven.doxia.tools.SiteTool getSiteTool() { return (org.apache.maven.doxia.tools.SiteTool)null;}
public  void setSiteTool(org.apache.maven.doxia.tools.SiteTool value) { }
public  boolean getFailOnError() { return false;}
public  boolean isFailOnError() { return false;}
public  void setFailOnError(boolean value) { }
public  boolean getFork() { return false;}
public  boolean isFork() { return false;}
public  void setFork(boolean value) { }
public  int getMaxHeap() { return (int)0;}
public  void setMaxHeap(int value) { }
public  int getTimeout() { return (int)0;}
public  void setTimeout(int value) { }
public  java.lang.String getJvmArgs() { return (java.lang.String)null;}
public  void setJvmArgs(java.lang.String value) { }
public  int getBugCount() { return (int)0;}
public  void setBugCount(int value) { }
public  int getErrorCount() { return (int)0;}
public  void setErrorCount(int value) { }
public  void execute() { }
}

==> spotbugs-maven-plugin-4.5.3.0-sources.jar: org/codehaus/mojo/spotbugs/SpotbugsViolationCheckMojo.java <==
package org.codehaus.mojo.spotbugs;
import java.lang.*;
import java.util.*;
import java.io.*;
import java.net.*;
import groovy.lang.*;
import groovy.util.*;

@org.apache.maven.plugins.annotations.Mojo(name="check", defaultPhase=org.apache.maven.plugins.annotations.LifecyclePhase.VERIFY, requiresDependencyResolution=org.apache.maven.plugins.annotations.ResolutionScope.TEST, requiresProject=true, threadSafe=true) @org.apache.maven.plugins.annotations.Execute(goal="spotbugs") public class SpotbugsViolationCheckMojo
  extends org.apache.maven.plugin.AbstractMojo  implements
    groovy.lang.GroovyObject {
;
@groovy.transform.Generated() @groovy.transform.Internal() @java.beans.Transient() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.io.File getOutputDirectory() { return (java.io.File)null;}
public  void setOutputDirectory(java.io.File value) { }
public  boolean getXmlOutput() { return false;}
public  boolean isXmlOutput() { return false;}
public  void setXmlOutput(boolean value) { }
public  java.io.File getXmlOutputDirectory() { return (java.io.File)null;}
public  void setXmlOutputDirectory(java.io.File value) { }
public  boolean getSpotbugsXmlOutput() { return false;}
public  boolean isSpotbugsXmlOutput() { return false;}
public  void setSpotbugsXmlOutput(boolean value) { }
public  java.io.File getSpotbugsXmlOutputDirectory() { return (java.io.File)null;}
public  void setSpotbugsXmlOutputDirectory(java.io.File value) { }
public  java.lang.String getSpotbugsXmlOutputFilename() { return (java.lang.String)null;}
public  void setSpotbugsXmlOutputFilename(java.lang.String value) { }
public  org.apache.maven.doxia.siterenderer.Renderer getSiteRenderer() { return (org.apache.maven.doxia.siterenderer.Renderer)null;}
public  void setSiteRenderer(org.apache.maven.doxia.siterenderer.Renderer value) { }
public  java.io.File getClassFilesDirectory() { return (java.io.File)null;}
public  void setClassFilesDirectory(java.io.File value) { }
public  java.io.File getTestClassFilesDirectory() { return (java.io.File)null;}
public  void setTestClassFilesDirectory(java.io.File value) { }
public  java.io.File getXrefLocation() { return (java.io.File)null;}
public  void setXrefLocation(java.io.File value) { }
public  java.io.File getXrefTestLocation() { return (java.io.File)null;}
public  void setXrefTestLocation(java.io.File value) { }
public  java.util.List getCompileSourceRoots() { return (java.util.List)null;}
public  void setCompileSourceRoots(java.util.List value) { }
public  java.util.List getTestSourceRoots() { return (java.util.List)null;}
public  void setTestSourceRoots(java.util.List value) { }
public  boolean getIncludeTests() { return false;}
public  boolean isIncludeTests() { return false;}
public  void setIncludeTests(boolean value) { }
public  java.util.List getPluginArtifacts() { return (java.util.List)null;}
public  void setPluginArtifacts(java.util.List value) { }
public  org.apache.maven.artifact.repository.ArtifactRepository getLocalRepository() { return (org.apache.maven.artifact.repository.ArtifactRepository)null;}
public  void setLocalRepository(org.apache.maven.artifact.repository.ArtifactRepository value) { }
public  java.util.List getRemoteArtifactRepositories() { return (java.util.List)null;}
public  void setRemoteArtifactRepositories(java.util.List value) { }
public  org.apache.maven.execution.MavenSession getSession() { return (org.apache.maven.execution.MavenSession)null;}
public  void setSession(org.apache.maven.execution.MavenSession value) { }
public  org.apache.maven.project.MavenProject getProject() { return (org.apache.maven.project.MavenProject)null;}
public  void setProject(org.apache.maven.project.MavenProject value) { }
public  java.lang.String getXmlEncoding() { return (java.lang.String)null;}
public  void setXmlEncoding(java.lang.String value) { }
public  java.lang.String getSourceEncoding() { return (java.lang.String)null;}
public  void setSourceEncoding(java.lang.String value) { }
public  java.lang.String getOutputEncoding() { return (java.lang.String)null;}
public  void setOutputEncoding(java.lang.String value) { }
public  java.lang.String getThreshold() { return (java.lang.String)null;}
public  void setThreshold(java.lang.String value) { }
public  org.apache.maven.shared.transfer.artifact.resolve.ArtifactResolver getArtifactResolver() { return (org.apache.maven.shared.transfer.artifact.resolve.ArtifactResolver)null;}
public  void setArtifactResolver(org.apache.maven.shared.transfer.artifact.resolve.ArtifactResolver value) { }
public  java.lang.String getIncludeFilterFile() { return (java.lang.String)null;}
public  void setIncludeFilterFile(java.lang.String value) { }
public  java.lang.String getExcludeFilterFile() { return (java.lang.String)null;}
public  void setExcludeFilterFile(java.lang.String value) { }
public  java.lang.String getExcludeBugsFile() { return (java.lang.String)null;}
public  void setExcludeBugsFile(java.lang.String value) { }
public  java.lang.String getEffort() { return (java.lang.String)null;}
public  void setEffort(java.lang.String value) { }
public  java.lang.Boolean getDebug() { return (java.lang.Boolean)null;}
public  java.lang.Boolean isDebug() { return (java.lang.Boolean)null;}
public  void setDebug(java.lang.Boolean value) { }
public  java.lang.Boolean getRelaxed() { return (java.lang.Boolean)null;}
public  java.lang.Boolean isRelaxed() { return (java.lang.Boolean)null;}
public  void setRelaxed(java.lang.Boolean value) { }
public  java.lang.String getVisitors() { return (java.lang.String)null;}
public  void setVisitors(java.lang.String value) { }
public  java.lang.String getOmitVisitors() { return (java.lang.String)null;}
public  void setOmitVisitors(java.lang.String value) { }
public  java.lang.String getPluginList() { return (java.lang.String)null;}
public  void setPluginList(java.lang.String value) { }
public  java.lang.String getOnlyAnalyze() { return (java.lang.String)null;}
public  void setOnlyAnalyze(java.lang.String value) { }
public  java.lang.Boolean getNested() { return (java.lang.Boolean)null;}
public  java.lang.Boolean isNested() { return (java.lang.Boolean)null;}
public  void setNested(java.lang.Boolean value) { }
public  java.lang.Boolean getTrace() { return (java.lang.Boolean)null;}
public  java.lang.Boolean isTrace() { return (java.lang.Boolean)null;}
public  void setTrace(java.lang.Boolean value) { }
public  int getMaxRank() { return (int)0;}
public  void setMaxRank(int value) { }
public  boolean getSkip() { return false;}
public  boolean isSkip() { return false;}
public  void setSkip(boolean value) { }
public  org.codehaus.plexus.resource.ResourceManager getResourceManager() { return (org.codehaus.plexus.resource.ResourceManager)null;}
public  void setResourceManager(org.codehaus.plexus.resource.ResourceManager value) { }
public  org.apache.maven.doxia.tools.SiteTool getSiteTool() { return (org.apache.maven.doxia.tools.SiteTool)null;}
public  void setSiteTool(org.apache.maven.doxia.tools.SiteTool value) { }
public  boolean getFailOnError() { return false;}
public  boolean isFailOnError() { return false;}
public  void setFailOnError(boolean value) { }
public  java.lang.String getFailThreshold() { return (java.lang.String)null;}
public  void setFailThreshold(java.lang.String value) { }
public  boolean getFork() { return false;}
public  boolean isFork() { return false;}
public  void setFork(boolean value) { }
public  int getMaxHeap() { return (int)0;}
public  void setMaxHeap(int value) { }
public  int getTimeout() { return (int)0;}
public  void setTimeout(int value) { }
public  java.lang.String getJvmArgs() { return (java.lang.String)null;}
public  void setJvmArgs(java.lang.String value) { }
public  int getMaxAllowedViolations() { return (int)0;}
public  void setMaxAllowedViolations(int value) { }
@java.lang.Override() public  void execute() { }
}
